@@ -64,6 +64,17 @@ class InstanceMixin:
 
         return Response({"instance": serializer.data})
 
+    def create(self, request, *args, **kwargs):
+        serializer = self.get_serializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
+        self.perform_create(serializer)
+        headers = self.get_success_headers(serializer.data)
+        return Response(
+            {"instance": serializer.data},
+            status=status.HTTP_201_CREATED,
+            headers=headers,
+        )
+
 
 class RepresentationModelViewSet(
     MetadataMixin, InstanceMixin, viewsets.ReadOnlyModelViewSet
